Release Notes
=============

Future releases
---------------
See issues on github at `<https://github.com/chrisdembia/yeadon/issues>`_

v1.0
----
 - Fairly thorough unit tests.
 - Clarified documentation and docstrings.
 - Improved the way rotation matrices are formed.
 - Moved visualization to the MayaVi library, and introduced a GUI.
 - Introduced the :py:meth:`yeadon.human.Human.inertia_transformed` method.
 - Use of python properties for inertia properties and other important
   attributes.
 - Improved setup/build/installation process.

v0.8 on 18 July 2011
--------------------
This is the first release.
